@@ -1,4 +1,5 @@
 from __future__ import absolute_import
+import fabric.api as fab
 import posixpath
 import os
 
@@ -11,10 +12,10 @@ def _select_bin(*commands, **kwargs):
     if not isinstance(commands, (list, tuple)):
         commands = [commands]
     if paths is None:
-        paths = (
+        paths = fab.env.get('deploy_bin_paths', (
             '/usr/bin',
             '/bin',
-        )
+        ))
     elif not isinstance(paths, (list, tuple)):
         paths = [paths]
     for path in paths:
